@@ -13,8 +13,8 @@
 package No::Worries::String;
 use strict;
 use warnings;
-our $VERSION  = "1.0";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.1";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
@@ -28,7 +28,8 @@ use Params::Validate qw(validate validate_pos :types);
 #
 
 our(
-    @_Map,   # mapping of characters to escaped strings
+    @_Map,     # mapping of characters to escaped strings
+    %_Plural,  # pluralization cache
 );
 
 #
@@ -46,11 +47,47 @@ sub string_escape ($) {
     return(join("", @list));
 }
 
+#
+# return the plural form of the given noun
+#
+
+sub string_plural ($) {
+    my($noun) = @_;
+
+    unless ($_Plural{$noun}) {
+        if ($noun =~ /(ch|s|sh|x|z)$/) {
+            $_Plural{$noun} = $noun . "es";
+        } elsif ($noun =~ /[bcdfghjklmnpqrstvwxz]y$/) {
+            $_Plural{$noun} = substr($noun, 0, -1) . "ies";
+        } elsif ($noun =~ /f$/) {
+            $_Plural{$noun} = substr($noun, 0, -1) . "ves";
+        } elsif ($noun =~ /fe$/) {
+            $_Plural{$noun} = substr($noun, 0, -2) . "ves";
+        } elsif ($noun =~ /[bcdfghjklmnpqrstvwxz]o$/) {
+            $_Plural{$noun} = $noun . "es";
+        } else {
+            $_Plural{$noun} = $noun . "s";
+        }
+    }
+    return($_Plural{$noun});
+}
+
+#
+# quantify the given (count, noun) pair
+#
+
+sub string_quantify ($$) {
+    my($count, $noun) = @_;
+
+    return($count . " " . ($count == 1 ? $noun : string_plural($noun)));
+}
+
 #
 # transform a table into a string
 #
 
 my %string_table_options = (
+    align   => { optional => 1, type => ARRAYREF },
     colsep  => { optional => 1, type => SCALAR },
     header  => { optional => 1, type => ARRAYREF },
     headsep => { optional => 1, type => SCALAR },
@@ -63,6 +100,7 @@ sub string_table ($@) {
     # handle options
     $lines = shift(@_);
     %option = validate(@_, \%string_table_options) if @_;
+    $option{align} ||= [];
     $option{colsep} = " | " unless defined($option{colsep});
     $option{headsep} = "=" unless defined($option{headsep});
     $option{indent} = "" unless defined($option{indent});
@@ -78,10 +116,17 @@ sub string_table ($@) {
     }
     # setup formatting
     $length = length($option{colsep}) * (@length - 1);
+    $index = 0;
     foreach my $colen (@length) {
         $length += $colen;
+        if ($option{align}[$index] and $option{align}[$index] eq "right") {
+            $colen = "%" . $colen . "s";
+        } else {
+            $colen = "%-" . $colen . "s";
+        }
+        $index++;
     }
-    $format = join($option{colsep}, map("%-${_}s", @length)) . "\n";
+    $format = join($option{colsep}, @length) . "\n";
     $result = "";
     # format header
     if ($option{header}) {
@@ -125,6 +170,15 @@ $_Map[ord("\n")] = "\\n";
 $_Map[ord("\r")] = "\\r";
 $_Map[ord("\e")] = "\\e";
 $_Map[ord("\\")] = "\\\\";
+%_Plural = (
+    "child" => "children",
+    "data"  => "data",
+    "foot"  => "feet",
+    "index" => "indices",
+    "man"   => "men",
+    "tooth" => "teeth",
+    "woman" => "women",
+);
 
 #
 # export control
@@ -134,7 +188,8 @@ sub import : method {
     my($pkg, %exported);
 
     $pkg = shift(@_);
-    grep($exported{$_}++, map("string_$_", qw(escape table trim)));
+    grep($exported{$_}++, map("string_$_",
+        qw(escape plural quantify table trim)));
     export_control(scalar(caller()), $pkg, \%exported, @_);
 }
 
@@ -148,11 +203,14 @@ No::Worries::String - string handling without worries
 
 =head1 SYNOPSIS
 
-  use No::Worries::String qw(string_escape string_table string_trim);
+  use No::Worries::String qw(*);
 
   # escape a string
   printf("found %s\n", string_escape($data));
 
+  # produce a nice output (e.g "1 file" or "3 files")
+  printf("found %s\n", string_quantify($count, "file"));
+
   # format a table
   print(string_table([
       [1, 1,  1],
@@ -165,29 +223,39 @@ No::Worries::String - string handling without worries
 
 =head1 DESCRIPTION
 
-This module eases string handling by providing convenient string
-manipulation functions.
+This module eases string handling by providing convenient string manipulation
+functions.
 
 =head1 FUNCTIONS
 
-This module provides the following functions (none of them being
-exported by default):
+This module provides the following functions (none of them being exported by
+default):
 
 =over
 
 =item string_escape(STRING)
 
-return a new string with all potentially non-printable characters
-escaped; this includes ASCII control characters, non-7bit ASCII and
-Unicode characters
+return a new string with all potentially non-printable characters escaped;
+this includes ASCII control characters, non-7bit ASCII and Unicode characters
+
+=item string_plural(STRING)
+
+assuming that STRING is an English noun, returns its plural form
+
+=item string_quantify(NUMBER, STRING)
+
+assuming that STRING is an English noun, returns a string saying how much of
+it there is; e.g. C<string_quantify(2, "foot")> is C<"2 feet">
 
 =item string_table(TABLE[, OPTIONS])
 
-transform the given table (a reference to an array of arrays of strings)
-into a formatted multi-line string; supported options:
+transform the given table (a reference to an array of arrays of strings) into
+a formatted multi-line string; supported options:
 
 =over
 
+=item * C<align>: array reference of alignment directions (default: left)
+
 =item * C<colsep>: column separator string (default: " | ")
 
 =item * C<header>: array reference of column headers (default: none)
@@ -212,4 +280,4 @@ L<No::Worries>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2012-2013
+Copyright (C) CERN 2012-2014
